﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

# Note that many of these screens may be given additional arguments in the
# future. The use of **kwargs in the parameter list ensures your code will
# work in the future.

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say(who, what, side_image=None, two_window=False):

    # Decide if we want to use the one-window or two-window variant.
    if not two_window:

        # The one window variant.
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:
                window:
                    style "say_who_window"

                    text who:
                        id "who"

            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"

    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):

    window:
        style "menu_window"
        xalign 0.5
        yalign 0.5

        vbox:
            style "menu"
            spacing 2

            for caption, action, chosen in items:

                if action:

                    button:
                        action action
                        style "menu_choice_button"

                        text caption style "menu_choice"

                else:
                    text caption style "menu_caption"

init -2:
    $ config.narrator_menu = True

    style menu_window is default

    style menu_choice is button_text:
        clear

    style menu_choice_button is button:
        xminimum int(config.screen_width * 0.75)
        xmaximum int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu

##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0

    use quick_menu

##############################################################################
# Main Menu
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    # This ensures that any other menu screen is replaced.
    tag menu

    # The background of the main menu.
    window:
        style "mm_root"

    # The main menu buttons.
    frame:
        style_group "mm"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Start Game") action Start()
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Gallery") action ShowMenu("cg_gallery")
        textbutton _("Tutorial") action Start("tutorial")
        textbutton _("About") action Start("about")
        textbutton _("Quit") action Quit(confirm=False)
        
label tutorial:
        
        stop music
        play music "tutorial.mp3" fadein 1.0
        
        scene bg start
        show bg tuto1
    
        "Probably you know how to play this kind of games, right?"
        "You only need to know 3 things"
        
        show bg tuto2
        
        "You have an inventory in the bag icon."
        "Sometimes, in the game you could see that eye."
        "That is the search mode, click on it to enter in that mode {p} and looking for items..."
        
        show bg tuto3
        
        "You will need some items to craft other useful items..."
        
        show bg tuto4
        
        "For example, the molotov..."
        
        show bg tuto5
        
        "The map works like the search mode..."
        "You need find the places to advance in the story."
        
        show bg tuto6
        
        "This is the combat mode..."
        "Be careful with the time, you only have some seconds to choose."
        "If you click in the right place you will defeat the mosnter."
        
        show bg start
        
        "Hope you like the game!"
        
        stop music fadeout 1.0
        
        return
        
label about:
    
        scene bg start
    
        "Hi ladies and gentlemen."
        "Thank you very much for playing this prologue of Delirium game." 
        "If you want tell me something, for example: {p}Your game is bored..."
        "My cat need a migo friend..."
        "Please email me to nikraria435@gmail.com"
        "I need say so much to {a=http://www.goldbargames.com/}Kinjo Goldbar{/a} for make the inventory system!"
        "You can find {a=http://www.goldbargames.com/}HERE{/a} more of his awesome job!"
        "Here, we will have a proper about, with the name of the people who made the music and he sound."
        scene bg credits1
        "...."
        "Thank you so much!"
        "You can find this and others awesome sounds in:"
        "{a=https://www.freesound.org}{/a}"
        "{a=freemusicarchive.org/}{/a}"
        "And thanks to the {a=http://www.renpy.org/}http://www.renpy.org/{/a}"
        "Oh! ... and excuse me bad english as usual please..."
        "Hope you like it!"
        "Kind regards!!"
        
        return

init -2:

    # Make all the main menu buttons be the same size.
    style mm_button:
        size_group "mm"



##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation():

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
    frame:
        style_group "gm_nav"
        xalign .98
        yalign .98

        has vbox

        textbutton _("Return") action Return()
        textbutton _("Preferences") action ShowMenu("preferences")
        textbutton _("Save Game") action ShowMenu("save")
        textbutton _("Load Game") action ShowMenu("load")
        textbutton _("Main Menu") action MainMenu()
        textbutton _("Quit") action Quit()

init -2:

    # Make all game menu navigation buttons the same size.
    style gm_nav_button:
        size_group "gm_nav"


##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.

screen file_picker:

    frame:
        style "file_picker_frame"

        has vbox

        # The buttons at the top allow the user to pick a
        # page of files.
        hbox:
            style_group "file_picker_nav"
            
            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)
                    
            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5
                
        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"
            
            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)
                    
                    $ file_name = FileSlotName(i, columns * rows)
                    $ file_time = FileTime(i, empty=_("Empty Slot."))
                    $ save_name = FileSaveName(i)

                    text "[file_name]. [file_time!t]\n[save_name!t]"

                    key "save_delete" action FileDelete(i)
                    
                    
screen save:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

screen load:

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)


##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences():

    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Display")
                textbutton _("Window") action Preference("display", "window")
                textbutton _("Fullscreen") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                has vbox

                label _("Transitions")
                textbutton _("All") action Preference("transitions", "all")
                textbutton _("None") action Preference("transitions", "none")

            frame:
                style_group "pref"
                has vbox

                label _("Text Speed")
                bar value Preference("text speed")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Joystick...") action Preference("joystick")


        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Skip")
                textbutton _("Seen Messages") action Preference("skip", "seen")
                textbutton _("All Messages") action Preference("skip", "all")

            frame:
                style_group "pref"
                has vbox

                textbutton _("Begin Skipping") action Skip()

            frame:
                style_group "pref"
                has vbox

                label _("After Choices")
                textbutton _("Stop Skipping") action Preference("after choices", "stop")
                textbutton _("Keep Skipping") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                has vbox

                label _("Auto-Forward Time")
                bar value Preference("auto-forward time")

                if config.has_voice:
                    textbutton _("Wait for Voice") action Preference("wait for voice", "toggle")

        vbox:
            frame:
                style_group "pref"
                has vbox

                label _("Music Volume")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                has vbox

                label _("Sound Volume")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton _("Test"):
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            if config.has_voice:
                frame:
                    style_group "pref"
                    has vbox

                    label _("Voice Volume")
                    bar value Preference("voice volume")

                    textbutton _("Voice Sustain") action Preference("voice sustain", "toggle")
                    if config.sample_voice:
                        textbutton _("Test"):
                            action Play("voice", config.sample_voice)
                            style "soundtest_button"

init -2:
    style pref_frame:
        xfill True
        xmargin 5
        top_margin 5

    style pref_vbox:
        xfill True

    style pref_button:
        size_group "pref"
        xalign 1.0

    style pref_slider:
        xmaximum 192
        xalign 1.0

    style soundtest_button:
        xalign 1.0


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt

screen yesno_prompt(message, yes_action, no_action):

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05

        has vbox:
            xalign .5
            yalign .5
            spacing 30

        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100

            textbutton _("Yes") action yes_action
            textbutton _("No") action no_action

    # Right-click and escape answer "no".
    key "game_menu" action no_action

init -2:
    style yesno_button:
        size_group "yesno"

    style yesno_label_text:
        text_align 0.5
        layout "subtitle"


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu():

    # Add an in-game quick menu.
 hbox:
        style_group "quickmenu"
   
        xalign 1.0
        yalign 0.0
       
        imagemap:
              ground "frameground"
              idle "frameground"
              selected_hover "framehover"
       
              hotspot (933,746,37,18) action ShowMenu("save")
              hotspot (973,747,42,19) action ShowMenu("load")
              hotspot (893,747,39,18) action Skip()

              
#        textbutton _("Search") action [ Jump ("search") ]
    
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 12
    style.quick_button_text.idle_color = "#8888"
    style.quick_button_text.hover_color = "#ccc"
    style.quick_button_text.selected_idle_color = "#cc08"
    style.quick_button_text.selected_hover_color = "#cc0"
    style.quick_button_text.insensitive_color = "#4448"
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
########################################################################################
#GALLERYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY
#definir imagenes de gallery
init:

  
    
    image cg china_hentai_1 = "china_hentai_1.png"
    image cg china_hentai_2 = "china_hentai_2.png"
    image cg china_hentai_3 = "china_hentai_3.png"
    image cg china_hentai_4 = "china_hentai_4.png"
    image cg china_hentai_5 = "china_hentai_5.png"
    image cg china_hentai_6 = "china_hentai_6.png"
    image cg eloise_atrap_1 = "atrapadai_1.png"
    image cg eloise_atrap_2 = "atrapadai_2.png"
    image cg eloise_atrap_3 = "atrapadai_3.png"
    image cg eloise_atrap_4 = "atrapadai_4.png"
    image cg eloise_atrap_5 = "atrapadai_5.png"
    image cg eloise_atrap_6 = "atrapadai_6.png"
    image cg eloise_atrap_7 = "atrapadai_7.png"
    image cg eloise_atrap_8 = "atrapadai_8.png"
    image cg eloise_atrap_9 = "atrapadai_9.png"
    image cg eloise_atrap_10 = "atrapadai_10.png"
    image cg eloise_atrap_11 = "atrapadai_11.png"
    image cg eloise_bella_1 = "Eloisebella_1.png"
    image cg eloise_bar_1 = "Eloisebarman_1.png"
    image cg eloise_bar_2 = "Eloisebarman_2.png"
    image cg eloise_bar_3 = "Eloisebarman_3.png"
    image cg eloise_bar_4 = "Eloisebarman_4.png"
    image cg eloise_tits_1 = "Eloisetits_1.png"
    image cg eloise_tits_2 = "Eloisetits_2.png"
    image cg eloise_tits_3 = "Eloisetits_3.png"
    image cg eloise_tits_4 = "Eloisetits_4.png"
    image cg eloise_ass_1 = "Eloiseass_1.png"
    image cg eloise_ass_2 = "Eloiseass_2.png"
    image cg eloise_ass_3 = "Eloiseass_3.png"
    image cg eloise_tits_2_1 = "Eloisetits_2_1.png"
    image cg eloise_tits_2_2 = "Eloisetits_2_2.png"
    image cg cementerio_1 = "hentaicemen_1.png"
    image cg cementerio_2 = "hentaicemen_2.png"
    image cg cementerio_3 = "hentaicemen_3.png"
    image cg hija_1 = "hentaihija_1.png"
    image cg hija_2 = "hentaihija_2.png"
    image cg hija_3 = "hentaihija_3.png"
    image cg hija_4 = "hentaihija_4.png"
    image cg hija_5 = "hentaihija_5.png"
    image cg hija_6 = "hentaihija_6.png"
    image cg hija_7 = "hentaihija_7.png"
    image cg hija_fuck_1 = "hijafuck_1.png"
    image cg hija_fuck_2 = "hijafuck_2.png"
    image cg hija_fuck_3 = "hijafuck_3.png"
    image cg hija_fuck_4 = "hijafuck_4.png"
    image cg monja_mamada_1 = "monjacuramamada_1.png"
    image cg monja_mamada_2 = "monjacuramamada_2.png"
    image cg monja_1 = "monjacura_1.png"
    image cg monja_2 = "monjacura_2.png"
    image cg monja_3 = "monjacura_3.png"
    image cg monja_4 = "monjacura_4.png"
    image cg eloise_roger_0 = "Eloise_rogerdad_0.png"
    image cg eloise_roger_1 = "Eloise_rogerdad_1.png"
    image cg eloise_roger_2 = "Eloise_rogerdad_2.png"
    image cg eloise_roger_3 = "Eloise_rogerdad_3.png"
    image cg eloise_roger_4 = "Eloise_rogerdad_4.png"
    image cg eloise_roger_5 = "Eloise_rogerdad_5.png"
    image cg eloise_roger_6 = "Eloise_rogerdad_6.png"
    image cg eloise_roger_7 = "Eloise_rogerdad_7.png"
    image cg eloise_roger_8 = "Eloise_rogerdad_8.png"
    image cg eloise_impulsor_1 = "Eloise_impulsor_1.png"
    image cg eloise_impulsor_2 = "Eloise_impulsor_2.png"
    image cg eloise_impulsor_3 = "Eloise_impulsor_3.png"
    image cg eloise_impulsor_4 = "Eloise_impulsor_4.png"
    image cg eloise_impulsor_5 = "Eloise_impulsor_5.png"
    image cg eloise_mamada_1 = "Eloise_mamada_nude_1.png"
    image cg eloise_mamada_2 = "Eloise_mamada_nude_2.png"
    image cg eloise_mamada_3 = "Eloise_mamada_nude_3.png"
    image cg eloise_mamada_4 = "Eloise_mamada_nude_4.png"
    image cg eloise_mamada_5 = "Eloise_mamada_nude_5.png"
    image cg eloise_mamada_6 = "Eloise_mamada_nude_6.png"
    image cg eloise_mamada_7 = "Eloise_mamada_nude_7.png"
    image cg grace_hentai_1 = "grace_hentai_1.png"
    image cg grace_hentai_2 = "grace_hentai_2.png"
    image cg grace_hentai_3 = "grace_hentai_3.png"
    image cg grace_hentai_4 = "grace_hentai_4.png"
    image cg grace_hentai_5 = "grace_hentai_5.png"
    image cg eloise_barquero_1 = "Eloise_barquero_1.png"
    image cg eloise_barquero_2 = "Eloise_barquero_2.png"
    image cg eloise_barquero_3 = "Eloise_barquero_3.png"
    image cg eloise_barquero_4 = "Eloise_barquero_4.png"
    image cg eloise_barquero_5 = "Eloise_barquero_5.png"
    image cg eloise_grace_1 = "eloise_grace_1.png"
    image cg eloise_grace_2 = "eloise_grace_2.png"
    image cg eloise_grace_3 = "eloise_grace_3.png"
    image cg eloise_grace_4 = "eloise_grace_4.png"
    image cg eloise_titjob_1 = "Eloise_titjob_1.png"
    image cg eloise_titjob_2 = "Eloise_titjob_2.png"
    image cg eloise_titjob_3 = "Eloise_titjob_3.png"
    image cg eloise_titjob_5 = "Eloise_titjob_5.png"
    image cg asylum_1 = "asylum_1.png"
    image cg asylum_2 = "asylum_2.png"
    image cg asylum_3 = "asylum_3.png"
    image cg asylum_4 = "asylum_4.png"
    image cg asylum_5 = "asylum_5.png"
    image cg asylum_6 = "asylum_6.png"
    image cg eloise_ritual_1 = "Eloise_ritual_1.png"
    image cg eloise_ritual_2 = "Eloise_ritual_2.png"
    

    
init python:

    #Galleries settings - start
    gallery_cg_items = [ "cg china_hentai_1", "cg china_hentai_2", "cg china_hentai_3", "cg china_hentai_4", "cg china_hentai_5", "cg china_hentai_6", "cg eloise_atrap_1", "cg eloise_atrap_2", "cg eloise_atrap_3", "cg eloise_atrap_4", "cg eloise_atrap_5", "cg eloise_atrap_6", "cg eloise_atrap_7", "cg eloise_atrap_8", "cg eloise_atrap_9", "cg eloise_atrap_10", "cg eloise_atrap_11", "cg eloise_bella_1", "cg eloise_bar_1", "cg eloise_bar_2", "cg eloise_bar_3", "cg eloise_bar_4", "cg eloise_tits_1", "cg eloise_tits_2", "cg eloise_tits_3", "cg eloise_tits_4", "cg eloise_ass_1", "cg eloise_ass_2", "cg eloise_ass_3", "cg eloise_tits_2_1", "cg eloise_tits_2_2", "cg cementerio_1", "cg cementerio_2", "cg cementerio_3", "cg hija_1", "cg hija_2", "cg hija_3", "cg hija_4", "cg hija_5", "cg hija_6", "cg hija_7", "cg hija_fuck_1", "cg hija_fuck_2", "cg hija_fuck_3", "cg hija_fuck_4", "cg monja_mamada_1", "cg monja_mamada_2", "cg monja_1", "cg monja_2", "cg monja_4", "cg eloise_roger_0", "cg eloise_roger_1", "cg eloise_roger_2", "cg eloise_roger_3", "cg eloise_roger_4", "cg eloise_roger_5", "cg eloise_roger_6", "cg eloise_roger_7", "cg eloise_roger_8", "cg eloise_impulsor_1", "cg eloise_impulsor_2", "cg eloise_impulsor_3", "cg eloise_impulsor_4", "cg eloise_impulsor_5", "cg eloise_mamada_1", "cg eloise_mamada_2", "cg eloise_mamada_3", "cg eloise_mamada_4", "cg eloise_mamada_5", "cg eloise_mamada_6", "cg eloise_mamada_7", "cg grace_hentai_1", "cg grace_hentai_2", "cg grace_hentai_3", "cg grace_hentai_4", "cg grace_hentai_5", "cg eloise_barquero_1", "cg eloise_barquero_2", "cg eloise_barquero_3", "cg eloise_barquero_4", "cg eloise_barquero_5", "cg eloise_grace_1", "cg eloise_grace_2", "cg eloise_grace_3", "cg eloise_grace_4", "cg eloise_titjob_1", "cg eloise_titjob_2", "cg eloise_titjob_3", "cg eloise_titjob_5", "cg asylum_1", "cg asylum_2", "cg asylum_3", "cg asylum_4", "cg asylum_5", "cg asylum_6", "cg eloise_ritual_1", "cg eloise_ritual_2",  ]
    #how many rows and columns in the gallery screens?
    gal_rows = 3
    gal_cols = 4
    #thumbnail size in pixels:
    thumbnail_x = 190
    thumbnail_y = 145
    #the setting above (267x150) will work well with 16:9 screen ratio. Make sure to adjust it, if your are using 4:3 or something else.
    #Galleries settings - end
   
    gal_cells = gal_rows * gal_cols   
    g_cg = Gallery()
    for gal_item in gallery_cg_items:
        g_cg.button(gal_item + " butt")
        g_cg.image(gal_item)
        g_cg.unlock(gal_item)
    g_cg.transition = fade
    cg_page=0
   
init +1 python:
    #Here we create the thumbnails. We create a grayscale thumbnail image for BGs, but we use a special "locked" image for CGs to prevent spoilers.
    for gal_item in gallery_cg_items:
        renpy.image (gal_item + " butt", im.Scale(ImageReference(gal_item), thumbnail_x, thumbnail_y))
       
screen cg_gallery:
    tag menu
    use navigation
    frame background None xpos 10:
        grid gal_rows gal_cols:
            ypos 10
            $ i = 0
            $ next_cg_page = cg_page + 1           
            if next_cg_page > int(len(gallery_cg_items)/gal_cells):
                $ next_cg_page = 0
            for gal_item in gallery_cg_items:
                $ i += 1
                if i <= (cg_page+1)*gal_cells and i>cg_page*gal_cells:
                    add g_cg.make_button(gal_item + " butt", gal_item + " butt", im.Scale("gallocked.png", thumbnail_x, thumbnail_y), xalign=0.5, yalign=0.5, idle_border=None, background=None, bottom_margin=24)
            for j in range(i, (cg_page+1)*gal_cells): #we need this to fully fill the grid
                null
        frame:
            yalign 0.97
            vbox:
                if len(gallery_cg_items)>gal_cells:
                    textbutton _("Next Page") action [SetVariable('cg_page', next_cg_page), ShowMenu("cg_gallery")]

